@@ -100,10 +100,7 @@ def OpenLevelUpWindow():
 	if GameCheck.IsBG1() or GameCheck.IsIWD1():
 		# armorclass
 		Label = LevelUpWindow.GetControl (0x10000057)
-		ac = GemRB.GetPlayerStat (pc, IE_ARMORCLASS)
-		#This is a temporary solution, the core engine should set the stat correctly!
-		ac += GemRB.GetAbilityBonus (IE_DEX, 2, GemRB.GetPlayerStat (pc, IE_DEX) )
-		Label.SetText (str (ac))
+		Label.SetText (str (GemRB.GetPlayerStat (pc, IE_ARMORCLASS)))
 		Label.SetTooltip (17183)
 
 		# hp now
@@ -248,6 +245,10 @@ def OpenLevelUpWindow():
 			Specialist = 0
 			if CommonTables.KitList.GetValue (Kit, 7) == 1: # see if we're a kitted mage
 				Specialist = 1
+
+			if Spellbook.HasSorcererBook (pc, Classes[i]):
+				MageTable = "SPLSRCKN"
+
 			MageTable = GemRB.LoadTable (MageTable)
 			# loop through each spell level and save the amount possible to cast (current)
 			for j in range (MageTable.GetColumnCount ()):
@@ -284,15 +285,16 @@ def OpenLevelUpWindow():
 					OldDSpells[j] = DruidTable.GetValue (str(StartLevel), str(j+1), GTV_INT)
 				DeltaDSpells = sum(NewDSpells)-sum(OldDSpells)
 
-		# setup class bonuses for this class
-		if IsMulti or IsDual or Kit == 0:
-			ABTable = CommonTables.ClassSkills.GetValue (TmpClassName, "ABILITIES")
-		else: # single-classed with a kit
-			ABTable = CommonTables.KitList.GetValue (str(Kit), "ABILITIES")
-
-		# add the abilites if we have a table to ref
-		if ABTable != "*" and GemRB.HasResource (ABTable, RES_2DA, 1):
-			GUICommon.AddClassAbilities (pc, ABTable, Level[i], LevelDiff[i])
+# this is handled by core
+#		# setup class bonuses for this class
+#		if IsMulti or IsDual or Kit == 0:
+#			ABTable = CommonTables.ClassSkills.GetValue (TmpClassName, "ABILITIES")
+#		else: # single-classed with a kit
+#			ABTable = CommonTables.KitList.GetValue (str(Kit), "ABILITIES")
+#
+#		# add the abilites if we have a table to ref
+#		if ABTable != "*" and GemRB.HasResource (ABTable, RES_2DA, 1):
+#			GUICommon.AddClassAbilities (pc, ABTable, Level[i], LevelDiff[i])
 
 	print "Actor CurrentLevels:",actor.Levels()
 	print "Levels:",Level,"Actor NextLevels:",actor.NextLevels()
@@ -377,8 +379,9 @@ def OpenLevelUpWindow():
 	LevelUpWindow.ShowModal (MODAL_SHADOW_GRAY)
 
 	# if we have a sorcerer who can learn spells, we need to do spell selection
-	if (Classes[0] == 19) and (DeltaWSpells > 0): # open our sorc spell selection window
-		LUSpellSelection.OpenSpellsWindow (pc, "SPLSRCKN", Level[0], LevelDiff[0])
+	for c in range(len(Classes)):
+		if Spellbook.HasSorcererBook (pc, Classes[c]) and DeltaWSpells > 0:
+			LUSpellSelection.OpenSpellsWindow (pc, "SPLSRCKN", Level[c], LevelDiff[c])
 
 def HideSkills(i):
 	"""Hides the given skill label from view."""
@@ -735,13 +738,3 @@ def ReactivateBaseClass ():
 				if Spellbook.HasSpell (pc, IE_SPELL_TYPE_PRIEST, i, Learnable[k]) < 0: # only write it if we don't yet know it
 					GemRB.LearnSpell(pc, Learnable[k])
 
-	# setup class bonuses for this class
-	if KitIndex == 0: # no kit
-		ABTable = CommonTables.ClassSkills.GetValue (ClassName, "ABILITIES")
-	else: # kit
-		ABTable = CommonTables.KitList.GetValue (KitIndex, 4, GTV_STR)
-	print "ABTable:",ABTable
-
-	# add the abilites if we have a table to ref
-	if ABTable != "*" and GemRB.HasResource (ABTable, RES_2DA, 1):
-		GUICommon.AddClassAbilities (pc, ABTable, Level[1], Level[1]) # relearn class abilites
